#!/bin/bash

#==============================================================================
# package manager
#==============================================================================

fun_pkg_sourced=1

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

[[ -n $fun_arch_sourced ]] || . $(dirname $BASH_SOURCE)/fun-arch.sh
export EPAGES_KERNEL EPAGES_ARCH

#------------------------------------------------------------------------------
# provide
#------------------------------------------------------------------------------

export pkg_instance pkg_installed

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

#..............................................................................
# pkg_instance
#..............................................................................
pkg_instance() {
  local USAGE='
syntax: pkg_instance NUMBER
NUMBER: 0 - remove last version of package
        1 - install the first time
        else - update (depending on the number of versions installed)
returns: first  - if NUMBER==1
         last   - if NUMBER==0
         update - else
'
  [[ $# -ne 1 || $1 != ${1#-} ]] && { echo "$USAGE" 1>&2; return 1; }

  [[ $1 = 1 ]] && { echo first; return; }
  [[ $1 = 0 ]] && { echo last; return; }
  echo update
}

#..............................................................................
# pkg_installed
#..............................................................................
pkg_installed() {
  local USAGE='
syntax: pkg_installed [-v] [-and|-or] PKG1 PKG2...
description: checks if epages-PKG is installed (-v for verbose)
returns: 1 - if all PKG1 PKG2... are installed
         1 - if one of PKG1 PKG2... is installed and -or is set
         0 - else
'
  [[ $# = 0 ]] && { echo "$USAGE" 1>&2; return 1; }
  [[ $1 != ${1#-} && $1 != -and && $1 != -or && $1 != -v ]] && { echo "$USAGE" 1>&2; return 1; }

  local pkg OR
  local QUIET=--quiet
  [[ $1 = -v ]] && { QUIET=; shift; }
  [[ $1 = -or ]] && OR=1 || OR=0
  [[ $1 != ${1#-} ]] && shift
  local all=$#
  local found=0

  for pkg in $@ ; do
    if [[ $pkg = pubkey && $EPAGES_KERNEL = ${EPAGES_KERNEL%d} ]] ; then
      rpm -qa | grep -qi gpg-pubkey-b1d28320- && found=$(($found + 1))
    elif [[ $EPAGES_KERNEL = ${EPAGES_KERNEL%d} ]] ; then
      rpm $QUIET -q epages-$pkg && found=$(($found + 1))
    elif [[ $pkg = pubkey ]] ; then
      apt-key list | grep -qi '/B1D28320 ' && found=$(($found + 1))
    elif [[ -n $QUIET ]] ; then
      dpkg --status epages-$pkg >/dev/null 2>&1 && found=$(($found + 1))
    else
      dpkg --status epages-$pkg && found=$(($found + 1))
    fi
  done
  [[ $found = $all || ( $found -gt 0 && $OR = 1 ) ]] && return 0
  return 1
}

#------------------------------------------------------------------------------
# end
# -----------------------------------------------------------------------------
